Title: Here is a title A->B: B->C: C->C: A->B: Normal line B-->C: Dashed line C->>D: Open arrow D-->>A: Dashed open arrow D->D: Self D->D: Many\nLines # Example of a comment. Note left of A: Note to the\n left of A Note right of A: Note to the\n right of A Note over A: Note over A Note over A,B: Note over both A and B participant long name\nC as C participant B participant A Note right of A: By listing the participants\n you can change their order